pods
===

<p align="left">
  <a href="https://github.com/lawrennd/ods"><img alt="GitHub Actions status" src="https://github.com/lawrennd/ods/workflows/code-tests/badge.svg"></a>
</p>

# Python open data science software. 

This repository contains utilities and tools for open data science including tools for accessing data sets in python. 




# Installation

```
pip install pods
```


## Release Notes

Note that from version 0.0.32-alpha non-data set loading functionality has been moved to other packages. Check [`goggles`](https://github.com/lawrennd/goggles), [`assessor`](https://github.com/lawrennd/assessor) and [`notutils`](https://github.com/lawrennd/notutils).

